import React from 'react';
import { storiesOf } from '@storybook/react';
import { withKnobs, boolean } from '@storybook/addon-knobs';
import Tour from '../Tour';
import Button from '../Button';
var targets = React.createElement(React.Fragment, null, React.createElement("div", {
  id: "one",
  style: {
    position: 'absolute',
    left: 20,
    top: 20,
    background: 'magenta',
    width: 40,
    height: 40
  }
}), React.createElement(Button, {
  id: "two",
  style: {
    position: 'relative',
    left: 200
  }
}, "I am a button!"), React.createElement("div", {
  id: "four",
  style: {
    position: 'absolute',
    left: 20,
    top: 280,
    background: 'green',
    width: 340,
    height: 40
  }
}), React.createElement("div", {
  id: "five",
  style: {
    position: 'absolute',
    left: -410,
    top: 30,
    background: 'red',
    width: 180,
    height: 180
  }
}), React.createElement("div", {
  id: "six",
  style: {
    position: 'absolute',
    left: 670,
    top: 20,
    background: 'orange',
    width: 40,
    height: 350
  }
}), React.createElement("div", {
  id: "three",
  style: {
    position: 'absolute',
    left: 20,
    top: 1800,
    background: 'orange',
    width: 40,
    height: 40
  }
}));
var steps = {
  default: function _default() {
    return [{
      selector: '#one',
      title: 'Welcome To The Tour',
      description: 'Use this component to point out new or important features.'
    }, {
      selector: '#two',
      movingTarget: true,
      title: 'Interaction',
      description: 'You can interact with the elements being highlighted.'
    }];
  },
  withFlipBeforeClose: function withFlipBeforeClose() {
    return [{
      selector: '#one',
      title: 'Welcome To The Tour',
      description: 'Without flipBeforeClose.'
    }, {
      selector: '#two',
      movingTarget: true,
      title: 'Interaction',
      description: 'With flipBeforeClose.',
      flipBeforeClose: true
    }];
  },
  scroll: function scroll() {
    return [{
      selector: '#one',
      title: 'Welcome To The Tour',
      description: 'Use this component to point out new or important features.'
    }, {
      selector: '#three',
      description: 'You can scroll to ofscreen elements'
    }];
  },
  secondaryTargets: function secondaryTargets() {
    return [{
      selector: '#one',
      title: 'Welcome To The Tour',
      description: 'Use this component to point out new or important features.',
      hidePrev: true,
      secondarySelectors: ['#four', '#five']
    }, {
      selector: '#two',
      movingTarget: true,
      title: 'Interaction',
      description: 'You can interact with the elements being highlighted.',
      hideNext: true,
      secondarySelectors: ['#one', '#four', '#six']
    }];
  }
};
storiesOf('Pattern|Tour', module).add('default', function () {
  return React.createElement(React.Fragment, null, targets, React.createElement(Tour, {
    steps: steps.default()
  }));
}).add('no mask', function () {
  return React.createElement(React.Fragment, null, targets, React.createElement(Tour, {
    steps: steps.default(),
    disableMask: true
  }));
}).addDecorator(withKnobs).add('with scrolling', function () {
  return React.createElement(React.Fragment, null, targets, React.createElement(Tour, {
    steps: steps.scroll(),
    disableAutoScroll: boolean('disable auto scroll', false),
    disableSmoothScroll: boolean('disable smooth scroll', false)
  }));
}).add('hide buttons', function () {
  return React.createElement(React.Fragment, null, targets, React.createElement(Tour, {
    steps: steps.default(),
    hidePrev: true,
    hideNext: true
  }));
}).add('with flip', function () {
  return React.createElement(React.Fragment, null, targets, React.createElement(Tour, {
    enableFlip: true,
    steps: steps.default(),
    flippedTitle: 'Flipped Title',
    flippedDescription: 'Secondary description on the back side of the card. Currently, this is the same for all steps'
  }));
}).add('with flip before close', function () {
  return React.createElement(React.Fragment, null, targets, React.createElement(Tour, {
    steps: steps.withFlipBeforeClose(),
    flippedTitle: 'Flipped Title',
    flippedDescription: 'Secondary description on the back side of the card. Currently, this is the same for all steps'
  }));
}).add('with secondary selectors and flip before close', function () {
  return React.createElement(React.Fragment, null, targets, React.createElement(Tour, {
    flipBeforeClose: true,
    steps: steps.secondaryTargets(),
    flippedTitle: 'Thanks for touring',
    flippedDescription: 'Secondary description on the back side of the card. Currently, this is the same for all steps'
  }));
});